# AI-Powered Meal Planner

An interactive meal planning application that uses AI to generate customized meal plans based on user preferences.

## Features

- **Customizable Meal Plans**: Set portions, flavors, allergies, and special instructions.
- **Comprehensive Output**: Get recipes, grocery lists, cooking instructions, and storage tips.
- **Calendar Integration**: Export meal plans to Google Calendar or other calendar apps.
- **Feedback System**: Refine your meal plan with AI-based improvements.
- **Save Configurations**: Save and load your favorite meal planning configurations.

## Project Structure

- **Components**: 
  - `ConfigForm`: Interface for setting meal plan preferences
  - `MealPlanDisplay`: Display generated meal plans in different views
  - `ExportTools`: Export meal plans to different formats
  - `SavedConfigs`: Save and load configuration profiles
  - `AIDebugPanel`: View AI prompts and responses (developer tool)
  - `RawMealPlanViewer`: View and copy the raw meal plan text
  - `MealPlanFeedback`: Submit feedback to refine meal plans

- **Services**:
  - `AIService`: Handles communication with AI model
  - `MealPlanService`: Processes and structures meal plan data

## Getting Started

### Prerequisites

- Node.js (v14 or later)
- npm or yarn

### Installation

1. Clone the repository:
   ```
   git clone https://github.com/yourusername/meal-planner.git
   cd meal-planner
   ```

2. Install dependencies:
   ```
   npm install
   ```

3. Start the development server:
   ```
   npm start
   ```

4. Open [http://localhost:3000](http://localhost:3000) in your browser.

## Usage

1. **Configure Preferences**:
   - Set the number of portions
   - Add liked/disliked flavors and styles
   - Add any food allergies
   - Add special instructions (e.g., "Friday is pizza night")
   - Select available cooking equipment

2. **Generate Meal Plan**:
   - Click the "Generate Meal Plan" button
   - The AI will create a customized meal plan based on your preferences

3. **View and Explore**:
   - Summary view: See all meals at a glance
   - Grocery list: Get a complete shopping list
   - Full recipes: Detailed recipes with ingredients and instructions
   - Calendar view: See your meals laid out on a calendar
   - Raw text: View the complete raw meal plan text

4. **Export**:
   - Export to Google Calendar (CSV)
   - Export to iCalendar (.ics)
   - Export to PDF

5. **Provide Feedback**:
   - Submit feedback to refine your meal plan
   - The AI will adjust the plan based on your preferences

## AI Integration

This application uses AI to generate meal plans. In a production environment, it would integrate with:

- OpenAI API (GPT models)
- Anthropic API (Claude models)
- Or another AI provider

The current implementation includes a simulated AI service for demonstration purposes.

## Future Enhancements

- Integration with grocery delivery services
- Nutritional analysis and diet tracking
- Recipe rating system
- Seasonal ingredient preferences
- Recipe scaling
- Ingredient substitution suggestions

## License

This project is licensed under the MIT License - see the LICENSE file for details.
