import React, { useState } from 'react';
import './AIDebugPanel.css';

const AIDebugPanel = ({ aiPrompt, rawAIResponse }) => {
  const [isExpanded, setIsExpanded] = useState(false);

  if (!aiPrompt) return null;

  return (
    <div className="ai-debug-panel">
      <div className="panel-header" onClick={() => setIsExpanded(!isExpanded)}>
        <h3>AI Interaction {isExpanded ? '▼' : '▶'}</h3>
        <span className="toggle-button">
          {isExpanded ? 'Hide' : 'Show'}
        </span>
      </div>
      
      {isExpanded && (
        <div className="panel-content">
          <div className="section">
            <h4>Prompt Sent to AI</h4>
            <pre className="code-block">{aiPrompt}</pre>
          </div>
          
          <div className="section">
            <h4>Raw AI Response</h4>
            <div className="response-container">
              {rawAIResponse ? (
                <pre className="code-block">{JSON.stringify(rawAIResponse, null, 2)}</pre>
              ) : (
                <p className="empty-message">No response available</p>
              )}
            </div>
          </div>
          
          <div className="panel-footer">
            <p>
              <strong>Note:</strong> In a production app, this panel would show the exact interaction with the AI model.
              You could use this to refine your prompts or understand the AI's reasoning.
            </p>
          </div>
        </div>
      )}
    </div>
  );
};

export default AIDebugPanel;
