import React, { useState } from 'react';
import Papa from 'papaparse';
import './ExportTools.css';

const ExportTools = ({ plan, calendarEvents }) => {
  const [exportFormat, setExportFormat] = useState('csv');
  const [exportType, setExportType] = useState('all');
  
  const handleExport = () => {
    // Use the calendarEvents from the service if available, otherwise use sample data
    const csvData = calendarEvents || [
      {
        Subject: 'Sample: Slow Cooker Pot Roast (8h30m|450cal)',
        Start_Date: '3/9/2025',
        Start_Time: '17:00',
        End_Date: '3/9/2025',
        End_Time: '18:00',
        All_Day_Event: 'False',
        Description: 'This is a sample event. Generate a meal plan to get real data.',
        Location: '',
        Private: 'False'
      }
    ];
    
    // Convert to CSV string
    const csv = Papa.unparse(csvData);
    
    // Create a download link
    const blob = new Blob([csv], { type: 'text/csv;charset=utf-8;' });
    const url = URL.createObjectURL(blob);
    const link = document.createElement('a');
    link.href = url;
    link.setAttribute('download', 'meal_plan_calendar.csv');
    document.body.appendChild(link);
    link.click();
    document.body.removeChild(link);
  };
  
  return (
    <div className="export-tools">
      <h2>Export Your Meal Plan</h2>
      
      <div className="export-options">
        <div className="form-group">
          <label htmlFor="exportFormat">Export Format:</label>
          <select
            id="exportFormat"
            value={exportFormat}
            onChange={(e) => setExportFormat(e.target.value)}
          >
            <option value="csv">CSV (Google Calendar)</option>
            <option value="pdf">PDF</option>
            <option value="ical">iCalendar (.ics)</option>
          </select>
        </div>
        
        <div className="form-group">
          <label htmlFor="exportType">Export Content:</label>
          <select
            id="exportType"
            value={exportType}
            onChange={(e) => setExportType(e.target.value)}
          >
            <option value="all">Complete Meal Plan</option>
            <option value="recipes">Recipes Only</option>
            <option value="groceries">Grocery Lists Only</option>
            <option value="calendar">Calendar Events Only</option>
          </select>
        </div>
      </div>
      
      <div className="export-actions">
        <button 
          className="export-button"
          onClick={handleExport}
        >
          Export Meal Plan
        </button>
      </div>
      
      <div className="export-help">
        <h3>Export Instructions</h3>
        <p>
          <strong>For Google Calendar:</strong> Export as CSV and import into Google Calendar using the "Import" option in Settings.
        </p>
        <p>
          <strong>For Apple Calendar:</strong> Export as iCalendar (.ics) and open the file with Apple Calendar.
        </p>
        <p>
          <strong>For Printing:</strong> Export as PDF for a printable version of your meal plan, recipes, and grocery lists.
        </p>
      </div>
    </div>
  );
};

export default ExportTools;
