import React, { useState } from 'react';
import './RawMealPlanViewer.css';

const RawMealPlanViewer = ({ rawPlan }) => {
  const [copied, setCopied] = useState(false);
  
  // Get the raw text from the AI response
  const mealPlanText = rawPlan?.text || 
    rawPlan?.rawResponse?.text || 
    rawPlan?.parsedAIResponse?.fullText || 
    // Fallback to placeholder text if no real response is available
    `# Meal Plan

## Summary Table

| Dish | Total Time | Calories | Date |
|------|------------|----------|------|
| Slow Cooker Pot Roast | 8h 30m | 450 | Sunday, Mar 9 |
| Spaghetti with Meat Sauce | 1h | 520 | Monday, Mar 10 |
| Chicken Stir-Fry | 35m | 380 | Tuesday, Mar 11 |
| ...more dishes... | ... | ... | ... |

## Grocery List
...

## Detailed Recipes
...

## Calendar View
...`;

  const handleCopyToClipboard = () => {
    navigator.clipboard.writeText(mealPlanText).then(() => {
      setCopied(true);
      setTimeout(() => setCopied(false), 2000);
    });
  };
  
  return (
    <div className="raw-meal-plan-viewer">
      <div className="viewer-header">
        <h3>Raw Meal Plan Text</h3>
        <button 
          className="copy-button"
          onClick={handleCopyToClipboard}
        >
          {copied ? 'Copied!' : 'Copy to Clipboard'}
        </button>
      </div>
      
      <div className="plan-content">
        <pre>{mealPlanText}</pre>
      </div>
      
      <div className="viewer-footer">
        <p>
          <strong>Note:</strong> In a production app, this would show the complete formatted text output from the AI model. 
          You can copy this and paste it elsewhere or send it to someone who doesn't have the app.
        </p>
      </div>
    </div>
  );
};

export default RawMealPlanViewer;
