// Service for generating meal plans
// Integrates with AIService for AI-based plan generation
import AIService from './AIService';

// Helper function to add days to a date
const addDays = (date, days) => {
  const result = new Date(date);
  result.setDate(result.getDate() + days);
  return result;
};

// Helper function to format a date to a string
const formatDate = (date) => {
  return date.toLocaleDateString('en-US', {
    weekday: 'long',
    month: 'short',
    day: 'numeric'
  });
};

// Sample recipes database (simplified)
const sampleRecipes = [
  {
    id: 1,
    name: 'Slow Cooker Pot Roast',
    prepTime: '30 minutes',
    cookTime: '8 hours',
    totalTime: '8 hours 30 minutes',
    calories: 450,
    category: 'american',
    equipment: ['slowcooker', 'oven'],
    ingredients: [
      { name: 'Chuck roast', amount: '3 lbs (1.36 kg)', perishable: true },
      { name: 'Carrots', amount: '4 large (about 300g)', perishable: true },
      { name: 'Potatoes', amount: '1.5 lbs (680g)', perishable: false },
      { name: 'Onion', amount: '1 large', perishable: true },
      { name: 'Beef broth', amount: '2 cups (480ml)', perishable: false },
      { name: 'Worcestershire sauce', amount: '2 tablespoons (30ml)', perishable: false },
      { name: 'Garlic', amount: '4 cloves', perishable: true },
      { name: 'Thyme', amount: '2 teaspoons dried', perishable: false },
      { name: 'Rosemary', amount: '1 teaspoon dried', perishable: false },
      { name: 'Salt', amount: '1 teaspoon', perishable: false },
      { name: 'Black pepper', amount: '1/2 teaspoon', perishable: false }
    ],
    instructions: [
      'Season chuck roast with salt and pepper.',
      'In a large skillet, sear the roast on all sides until browned.',
      'Place carrots, potatoes, and onion in the bottom of a slow cooker.',
      'Place the seared roast on top of the vegetables.',
      'Mix beef broth and Worcestershire sauce together, then pour over the roast.',
      'Add minced garlic, thyme, and rosemary.',
      'Cover and cook on low for 8 hours.',
      'Remove the roast and let rest for 10 minutes before slicing.',
      'Serve with the vegetables and cooking liquid.'
    ],
    storage: 'Refrigerate in airtight containers for up to 3 days. Can be frozen for up to 3 months.',
    notes: 'Pull roast from freezer the night before and place in refrigerator to thaw.'
  },
  {
    id: 2,
    name: 'Spaghetti with Meat Sauce',
    prepTime: '15 minutes',
    cookTime: '45 minutes',
    totalTime: '1 hour',
    calories: 520,
    category: 'italian',
    equipment: ['stove'],
    ingredients: [
      { name: 'Ground beef', amount: '1.5 lbs (680g)', perishable: true },
      { name: 'Spaghetti', amount: '1 lb (454g)', perishable: false },
      { name: 'Tomato sauce', amount: '28 oz can', perishable: false },
      { name: 'Diced tomatoes', amount: '14.5 oz can', perishable: false },
      { name: 'Onion', amount: '1 medium', perishable: true },
      { name: 'Garlic', amount: '3 cloves', perishable: true },
      { name: 'Olive oil', amount: '2 tablespoons (30ml)', perishable: false },
      { name: 'Italian seasoning', amount: '1 tablespoon', perishable: false },
      { name: 'Salt', amount: 'to taste', perishable: false },
      { name: 'Black pepper', amount: 'to taste', perishable: false },
      { name: 'Parmesan cheese', amount: '1/2 cup grated (50g)', perishable: true }
    ],
    instructions: [
      'In a large pot, bring salted water to a boil for the pasta.',
      'In a large skillet, heat olive oil over medium heat.',
      'Add diced onion and cook until translucent, about 5 minutes.',
      'Add minced garlic and cook for 30 seconds until fragrant.',
      'Add ground beef and cook until browned, about 7-8 minutes, breaking it up as it cooks.',
      'Drain excess fat if necessary.',
      'Add tomato sauce, diced tomatoes, and Italian seasoning.',
      'Bring to a simmer, then reduce heat to low and cook for 30 minutes, stirring occasionally.',
      'Meanwhile, cook spaghetti according to package directions until al dente.',
      'Drain pasta and return to the pot.',
      'Season meat sauce with salt and pepper to taste.',
      'Serve pasta topped with meat sauce and grated Parmesan cheese.'
    ],
    storage: 'Refrigerate sauce separately from pasta in airtight containers for up to 4 days. Can be frozen for up to 3 months.',
    notes: 'Sauce can be made ahead of time and refrigerated.'
  },
  {
    id: 3,
    name: 'Chicken Stir-Fry',
    prepTime: '20 minutes',
    cookTime: '15 minutes',
    totalTime: '35 minutes',
    calories: 380,
    category: 'asian',
    equipment: ['stove'],
    ingredients: [
      { name: 'Chicken breast', amount: '1.5 lbs (680g)', perishable: true },
      { name: 'Broccoli', amount: '3 cups chopped (about 270g)', perishable: true },
      { name: 'Bell peppers', amount: '2 medium', perishable: true },
      { name: 'Carrots', amount: '2 medium', perishable: true },
      { name: 'Snap peas', amount: '1 cup (about 150g)', perishable: true },
      { name: 'Garlic', amount: '3 cloves', perishable: true },
      { name: 'Ginger', amount: '1 tablespoon minced', perishable: true },
      { name: 'Soy sauce', amount: '3 tablespoons (45ml)', perishable: false },
      { name: 'Sesame oil', amount: '1 tablespoon (15ml)', perishable: false },
      { name: 'Cornstarch', amount: '1 tablespoon', perishable: false },
      { name: 'Vegetable oil', amount: '2 tablespoons (30ml)', perishable: false },
      { name: 'Rice', amount: '2 cups uncooked (about 400g)', perishable: false }
    ],
    instructions: [
      'Slice chicken into thin strips. Mix with 1 tablespoon soy sauce and cornstarch.',
      'Prepare rice according to package instructions.',
      'Heat 1 tablespoon vegetable oil in a wok or large skillet over high heat.',
      'Add chicken and stir-fry for 4-5 minutes until golden and cooked through. Remove from pan.',
      'Add remaining vegetable oil to the pan.',
      'Add garlic and ginger and stir-fry for 30 seconds until fragrant.',
      'Add vegetables and stir-fry for 5-6 minutes until crisp-tender.',
      'Return chicken to the pan and add remaining soy sauce and sesame oil.',
      'Stir well to combine and cook for another 1-2 minutes.',
      'Serve over rice.'
    ],
    storage: 'Refrigerate in airtight containers for up to 3 days.',
    notes: 'Vegetables can be prepped a day ahead and stored in the refrigerator.'
  },
  // More recipes would be added in a real application
];

// Main API service object
const MealPlanService = {
  // Generate a meal plan based on the provided configuration
  generateMealPlan: async (config) => {
    try {
      // Build prompt for AI
      const prompt = AIService.buildPrompt(config);
      
      // Call AI service
      const aiResponse = await AIService.generateWithAI(prompt);
      
      // Process the AI response to extract structured data
      const parsedResponse = AIService.parseAIResponse(aiResponse);
      
      // We're using a hybrid approach for now - we'll use our sample data
      // but also include the raw AI response and parsed sections
      
      // For demonstration purposes, we'll create a simple meal plan
      const startDate = new Date(config.startDate);

      // Calculate interval duration in days based on config
      let intervalDurationInDays;
      switch (config.shoppingIntervalUnit) {
        case 'day':
          intervalDurationInDays = config.shoppingIntervalQuantity;
          break;
        case 'week':
          intervalDurationInDays = config.shoppingIntervalQuantity * 7;
          break;
        // TODO: Handle 'month' unit if needed
        default:
          // Default to 7 days (1 week) if unit is unknown or month
          intervalDurationInDays = 7;
          console.warn(`Unknown shoppingIntervalUnit: ${config.shoppingIntervalUnit}. Defaulting to 7 days per interval.`);
      }

      const totalIntervals = config.numberOfIntervals;

      // Generate meal assignments and grocery lists per interval
      const meals = [];
      const groceryLists = [];

      // Use the parsed AI response to populate meals and grocery lists
      if (parsedResponse && parsedResponse.success && parsedResponse.parsedData) {
        const { summaryTable, groceryList, detailedRecipes, calendarView } = parsedResponse.parsedData;

        // Parse markdown tables/text into structured data
        // This is a simplified parsing logic and may need refinement based on actual AI output format
        const parseSummaryTable = (markdown) => {
          const lines = markdown.split('\n').filter(line => line.trim() !== '' && !line.startsWith('| :'));
          const headers = lines[0].split('|').map(h => h.trim()).filter(h => h !== '');
          const rows = lines.slice(1).map(line => {
            const values = line.split('|').map(v => v.trim()).filter(v => v !== '');
            const rowData = {};
            headers.forEach((header, index) => {
              rowData[header] = values[index];
            });
            // Attempt to extract date and create a Date object
            const dateString = rowData['Date'];
            let date = null;
            if (dateString) {
              try {
                date = new Date(dateString);
                // Basic validation to check if the date is valid
                if (isNaN(date.getTime())) {
                  date = null; // Invalid date
                }
              } catch (e) {
                date = null; // Parsing error
              }
            }
            return {
              id: rowData['Dish Name'] ? rowData['Dish Name'].replace(/\s+/g, '-') : `meal-${Math.random()}`, // Simple ID generation
              name: rowData['Dish Name'] || 'Unknown Dish',
              totalTime: rowData['Total Time (Approx.)'] || 'N/A',
              calories: parseInt(rowData['Approx. Calories (per serving)']) || 0,
              date: date,
              // Placeholder for other meal details (ingredients, instructions, etc.)
              ingredients: [],
              instructions: [],
              storage: '',
              notes: ''
            };
          });
          return rows;
        };

        const parseGroceryList = (markdown) => {
           const lines = markdown.split('\n').filter(line => line.trim() !== '' && !line.startsWith('| :'));
           const headers = lines[0].split('|').map(h => h.trim()).filter(h => h !== '');
           const rows = lines.slice(1).map(line => {
             const values = line.split('|').map(v => v.trim()).filter(v => v !== '');
             const rowData = {};
             headers.forEach((header, index) => {
               rowData[header] = values[index];
             });
             return {
               name: rowData['Ingredient Name'] || 'Unknown Ingredient',
               amount: rowData['Total Quantity (Volume/Weight)'] || 'N/A',
               perishable: rowData['Is Perishable'] ? rowData['Is Perishable'].toLowerCase() === 'yes' : false,
               notes: rowData['Notes / Bulk Suggestion'] || ''
             };
           });

           // Group grocery items by interval if the AI provides this structure
           // This is a simplified assumption based on the AI's potential output
           // A more robust solution might require AI to explicitly structure grocery lists by interval
           const groupedGroceryLists = [{
             intervalNumber: 1, // Assuming a single list for the entire plan for now
             startDate: startDate, // Use the plan start date
             endDate: addDays(startDate, intervalDurationInDays * totalIntervals - 1), // Calculate end date
             items: rows
           }];

           return groupedGroceryLists;
        };

        // Simplified parsing for recipes - just extracting the text for now
        // A more advanced parser would break this down into individual recipes, ingredients, instructions, etc.
        const parseDetailedRecipes = (markdown) => {
          // For now, return the raw markdown text.
          // The MealPlanDisplay component will need to handle rendering this markdown.
          return markdown;
        };

        // Simplified parsing for calendar view - just extracting the text for now
        const parseCalendarView = (markdown) => {
           // For now, return the raw markdown text.
           // The MealPlanDisplay component will need to handle rendering this markdown.
           return markdown;
        };


        // Populate meals and grocery lists by parsing the markdown content
        const parsedMeals = parseSummaryTable(summaryTable);
        const parsedGroceryLists = parseGroceryList(groceryList);
        const parsedDetailedRecipes = parseDetailedRecipes(detailedRecipes);
        const parsedCalendarView = parseCalendarView(calendarView);


        // Merge parsed data into the final meal plan structure
        // This part needs to align with how MealPlanDisplay expects the data
        // For now, we'll use the parsedMeals and parsedGroceryLists directly
        // and include the raw markdown for recipes and calendar for display
        meals.push(...parsedMeals);
        groceryLists.push(...parsedGroceryLists);


      } else {
        // Fallback or error handling if AI response parsing failed
        console.error("AI response parsing failed or returned no data.");
        // Optionally, add logic here to generate a basic plan or throw an error
        // For now, we'll return an empty plan if parsing failed.
      }
      
      return {
        config,
        totalIntervals, // Changed from weeks
        startDate,
        meals,
        groceryLists,
        aiPrompt: prompt, // Store the prompt for reference
        rawAIResponse: aiResponse, // This contains the raw response from the AI
        parsedAIResponse: parsedResponse // This contains the parsed sections
      };
    } catch (error) {
      console.error('Error generating meal plan:', error);
      throw error;
    }
  },
  
  // Generate calendar events for the meal plan
  generateCalendarEvents: (mealPlan) => {
    return new Promise((resolve) => {
      setTimeout(() => {
        const events = [];
        
        // Add meal events
        mealPlan.meals.forEach(meal => {
          // Recipe event
          events.push({
            Subject: `${meal.name} (${meal.totalTime}|${meal.calories}cal)`,
            Start_Date: meal.date.toLocaleDateString('en-US', {year: 'numeric', month: 'numeric', day: 'numeric'}),
            Start_Time: '17:00', // Default dinner time
            End_Date: meal.date.toLocaleDateString('en-US', {year: 'numeric', month: 'numeric', day: 'numeric'}),
            End_Time: '18:00', // Assume 1 hour for meal
            All_Day_Event: 'False',
            Description: `Ingredients:\n${meal.ingredients.map(ing => `- ${ing.name}: ${ing.amount}`).join('\n')}\n\nInstructions:\n${meal.instructions.map((step, i) => `${i+1}. ${step}`).join('\n')}`,
            Location: '',
            Private: 'False'
          });
          
          // Add prep events if needed
          if (meal.notes && meal.notes.toLowerCase().includes('thaw')) {
            const prepDate = new Date(meal.date);
            prepDate.setDate(prepDate.getDate() - 1); // Day before
            
            events.push({
              Subject: `PREP: Thaw for ${meal.name}`,
              Start_Date: prepDate.toLocaleDateString('en-US', {year: 'numeric', month: 'numeric', day: 'numeric'}),
              Start_Time: '20:00',
              End_Date: prepDate.toLocaleDateString('en-US', {year: 'numeric', month: 'numeric', day: 'numeric'}),
              End_Time: '20:15',
              All_Day_Event: 'False',
              Description: `Move ingredients from freezer to refrigerator for tomorrow's ${meal.name}`,
              Location: '',
              Private: 'False'
            });
          }
        });
        
        // Add grocery shopping events
        mealPlan.groceryLists.forEach(list => {
          events.push({
            Subject: `Grocery Shopping (Week ${list.intervalNumber})`,
            Start_Date: list.startDate.toLocaleDateString('en-US', {year: 'numeric', month: 'numeric', day: 'numeric'}),
            Start_Time: '10:00',
            End_Date: list.startDate.toLocaleDateString('en-US', {year: 'numeric', month: 'numeric', day: 'numeric'}),
            End_Time: '11:30',
            All_Day_Event: 'False',
            Description: `Grocery list:\n${list.items.map(item => `- ${item.name}: ${item.amount} ${item.perishable ? '(Perishable)' : ''}`).join('\n')}`,
            Location: '',
            Private: 'False'
          });
        });
        
        resolve(events);
      }, 500);
    });
  }
};

export default MealPlanService;
